@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
+import packaging.version
 import pkg_resources
 
-from google import auth  # type: ignore
-from google.api_core import exceptions  # type: ignore
+import google.auth  # type: ignore
+import google.api_core  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 
-from google.api import service_pb2 as service  # type: ignore
+from google.api import service_pb2  # type: ignore
 from google.cloud.servicemanagement_v1.types import resources
 from google.cloud.servicemanagement_v1.types import servicemanager
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -41,6 +41,15 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
+try:
+    # google.auth.__version__ was added in 1.26.0
+    _GOOGLE_AUTH_VERSION = google.auth.__version__
+except AttributeError:
+    try:  # try pkg_resources if it is available
+        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
+    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
+        _GOOGLE_AUTH_VERSION = None
+
 
 class ServiceManagerTransport(abc.ABC):
     """Abstract transport class for ServiceManager."""
@@ -52,21 +61,25 @@ class ServiceManagerTransport(abc.ABC):
         "https://www.googleapis.com/auth/service.management.readonly",
     )
 
+    DEFAULT_HOST: str = "servicemanagement.googleapis.com"
+
     def __init__(
         self,
         *,
-        host: str = "servicemanagement.googleapis.com",
-        credentials: credentials.Credentials = None,
-        credentials_file: typing.Optional[str] = None,
-        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-        quota_project_id: typing.Optional[str] = None,
+        host: str = DEFAULT_HOST,
+        credentials: ga_credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -75,7 +88,7 @@ class ServiceManagerTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):
@@ -83,35 +96,70 @@ class ServiceManagerTransport(abc.ABC):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
         self._host = host
 
+        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+
         # Save the scopes.
-        self._scopes = scopes or self.AUTH_SCOPES
+        self._scopes = scopes
 
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs(
+            raise core_exceptions.DuplicateCredentialArgs(
                 "'credentials_file' and 'credentials' are mutually exclusive"
             )
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=self._scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.load_credentials_from_file(
+                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
-            credentials, _ = auth.default(
-                scopes=self._scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.default(
+                **scopes_kwargs, quota_project_id=quota_project_id
             )
 
+        # If the credentials is service account credentials, then always try to use self signed JWT.
+        if (
+            always_use_jwt_access
+            and isinstance(credentials, service_account.Credentials)
+            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
+        ):
+            credentials = credentials.with_always_use_jwt_access(True)
+
         # Save the credentials.
         self._credentials = credentials
 
+    # TODO(busunkim): This method is in the base transport
+    # to avoid duplicating code across the transport classes. These functions
+    # should be deleted once the minimum required versions of google-auth is increased.
+
+    # TODO: Remove this function once google-auth >= 1.25.0 is required
+    @classmethod
+    def _get_scopes_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Optional[Sequence[str]]]:
+        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
+
+        scopes_kwargs = {}
+
+        if _GOOGLE_AUTH_VERSION and (
+            packaging.version.parse(_GOOGLE_AUTH_VERSION)
+            >= packaging.version.parse("1.25.0")
+        ):
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
+        else:
+            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
+
+        return scopes_kwargs
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -182,11 +230,11 @@ class ServiceManagerTransport(abc.ABC):
     @property
     def list_services(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.ListServicesRequest],
-        typing.Union[
+        Union[
             servicemanager.ListServicesResponse,
-            typing.Awaitable[servicemanager.ListServicesResponse],
+            Awaitable[servicemanager.ListServicesResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -194,49 +242,47 @@ class ServiceManagerTransport(abc.ABC):
     @property
     def get_service(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.GetServiceRequest],
-        typing.Union[
-            resources.ManagedService, typing.Awaitable[resources.ManagedService]
-        ],
+        Union[resources.ManagedService, Awaitable[resources.ManagedService]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_service(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.CreateServiceRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def delete_service(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.DeleteServiceRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def undelete_service(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.UndeleteServiceRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_service_configs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.ListServiceConfigsRequest],
-        typing.Union[
+        Union[
             servicemanager.ListServiceConfigsResponse,
-            typing.Awaitable[servicemanager.ListServiceConfigsResponse],
+            Awaitable[servicemanager.ListServiceConfigsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -244,38 +290,38 @@ class ServiceManagerTransport(abc.ABC):
     @property
     def get_service_config(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.GetServiceConfigRequest],
-        typing.Union[service.Service, typing.Awaitable[service.Service]],
+        Union[service_pb2.Service, Awaitable[service_pb2.Service]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_service_config(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.CreateServiceConfigRequest],
-        typing.Union[service.Service, typing.Awaitable[service.Service]],
+        Union[service_pb2.Service, Awaitable[service_pb2.Service]],
     ]:
         raise NotImplementedError()
 
     @property
     def submit_config_source(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.SubmitConfigSourceRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_service_rollouts(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.ListServiceRolloutsRequest],
-        typing.Union[
+        Union[
             servicemanager.ListServiceRolloutsResponse,
-            typing.Awaitable[servicemanager.ListServiceRolloutsResponse],
+            Awaitable[servicemanager.ListServiceRolloutsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -283,29 +329,29 @@ class ServiceManagerTransport(abc.ABC):
     @property
     def get_service_rollout(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.GetServiceRolloutRequest],
-        typing.Union[resources.Rollout, typing.Awaitable[resources.Rollout]],
+        Union[resources.Rollout, Awaitable[resources.Rollout]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_service_rollout(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.CreateServiceRolloutRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def generate_config_report(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.GenerateConfigReportRequest],
-        typing.Union[
+        Union[
             servicemanager.GenerateConfigReportResponse,
-            typing.Awaitable[servicemanager.GenerateConfigReportResponse],
+            Awaitable[servicemanager.GenerateConfigReportResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -313,18 +359,18 @@ class ServiceManagerTransport(abc.ABC):
     @property
     def enable_service(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.EnableServiceRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def disable_service(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [servicemanager.DisableServiceRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
